==> icewm_1.4.3.0~pre-20171002.orig.tar.xz: icewm-1.4.3.0~pre-20171002/src/wmapp.h <==
#ifndef __WMAPP_H
#define __WMAPP_H

#include "ysmapp.h"
#include "ymenu.h"
#include "ymsgbox.h"
#ifdef CONFIG_GUIEVENTS
#include "guievent.h"
#endif

class YWindowManager;
class AboutDlg;
class CtrlAltDelete;
class SwitchWindow;

enum FocusModels {
    FocusCustom,
    FocusClick,
    FocusSloppy,
    FocusExplicit,
    FocusStrict,
    FocusQuiet,
    FocusModelCount,
    FocusModelLast = FocusModelCount - 1
};

class YSMListener {
public:
    virtual void handleSMAction(int message) = 0;
    virtual void restartClient(const char *path, char *const *args) = 0;
    virtual void runOnce(const char *resource, const char *path, char *const *args) = 0;
    virtual void runCommandOnce(const char *resource, const char *cmdline) = 0;
protected:
    virtual ~YSMListener() {}; 
};

class YWMApp: 
    public YSMApplication, 
    public YActionListener, 
    public YMsgBoxListener, 
    public YSMListener
{
public:
    YWMApp(int *argc, char ***argv, const char *displayName = 0);
    ~YWMApp();
#ifdef CONFIG_GUIEVENTS
    void signalGuiEvent(GUIEvent ge);
#endif

    virtual void afterWindowEvent(XEvent &xev);
    virtual void handleSignal(int sig);
    virtual bool handleIdle();
    virtual bool filterEvent(const XEvent &xev);
    virtual void actionPerformed(YAction *action, unsigned int modifiers);

    virtual void handleMsgBox(YMsgBox *msgbox, int operation);
    virtual void handleSMAction(int message);

    void doLogout();
    void logout();
    void cancelLogout();

#ifdef CONFIG_SESSION
    virtual void smSaveYourselfPhase2();
    virtual void smDie();
#endif

#ifndef NO_CONFIGURE
    void setFocusMode(int mode);
#endif
    void initFocusMode();

    virtual void restartClient(const char *path, char *const *args);
    virtual void runOnce(const char *resource, const char *path, char *const *args);
    virtual void runCommandOnce(const char *resource, const char *cmdline);

    static YCursor sizeRightPointer;
    static YCursor sizeTopRightPointer;
    static YCursor sizeTopPointer;
    static YCursor sizeTopLeftPointer;
    static YCursor sizeLeftPointer;
    static YCursor sizeBottomLeftPointer;
    static YCursor sizeBottomPointer;
    static YCursor sizeBottomRightPointer;
    static YCursor scrollLeftPointer;
    static YCursor scrollRightPointer;
    static YCursor scrollUpPointer;
    static YCursor scrollDownPointer;

#ifndef LITE
    static ref<YIcon> getDefaultAppIcon();

    bool hasCtrlAltDelete() const { return ctrlAltDelete != 0; }
    CtrlAltDelete* getCtrlAltDelete();
#endif
    bool hasSwitchWindow() const { return switchWindow != 0; }
    SwitchWindow* getSwitchWindow();

private:
    char** mainArgv;
    YMsgBox *fLogoutMsgBox;
    AboutDlg* aboutDlg;
#ifndef LITE
    CtrlAltDelete* ctrlAltDelete;
#endif
    SwitchWindow* switchWindow;

    void runRestart(const char *path, char *const *args);

    Window managerWindow;

    static void initAtoms();
    static void initPointers();
#ifndef LITE
    static void initIcons();
    static void termIcons();
#endif
    static void initIconSize();
    static void initPixmaps();
};

extern YWMApp * wmapp;

extern YMenu *windowMenu;
extern YMenu *layerMenu;
extern YMenu *moveMenu;

#ifdef CONFIG_TRAY
extern YMenu *trayMenu;
#endif

#ifdef CONFIG_WINMENU
extern YMenu *windowListMenu;
#endif

#ifdef CONFIG_WINLIST
extern YMenu *windowListPopup;
extern YMenu *windowListAllPopup;
#endif

extern YMenu *logoutMenu;

#ifndef NO_CONFIGURE_MENUS
class ObjectMenu;
extern ObjectMenu *rootMenu;

class KProgram;
extern YObjectArray<KProgram> keyProgs;
#endif
extern int rebootOrShutdown;

#endif

==> icewm-1.5.4.tar.xz: icewm-1.5.4/src/wmapp.h <==
#ifndef __WMAPP_H
#define __WMAPP_H

#include "ysmapp.h"
#include "ymenu.h"
#include "ymsgbox.h"
#include "guievent.h"

class YWindowManager;
class AboutDlg;
class CtrlAltDelete;
class SwitchWindow;

enum FocusModels {
    FocusCustom,
    FocusClick,
    FocusSloppy,
    FocusExplicit,
    FocusStrict,
    FocusQuiet,
    FocusModelLast = FocusQuiet
};

class YSMListener {
public:
    virtual void handleSMAction(WMAction message) = 0;
    virtual void restartClient(const char *path, char *const *args) = 0;
    virtual void runOnce(const char *resource, long *pid,
                         const char *path, char *const *args) = 0;
    virtual void runCommandOnce(const char *resource, const char *cmdline, long *pid) = 0;
protected:
    virtual ~YSMListener() {}
};

class YWMApp:
    public YSMApplication,
    public YActionListener,
    public YMsgBoxListener,
    public YSMListener
{
public:
    YWMApp(int *argc, char ***argv, const char *displayName,
            const char *configFile, const char *overrideTheme);
    ~YWMApp();
    void signalGuiEvent(GUIEvent ge);

    virtual void afterWindowEvent(XEvent &xev);
    virtual void handleSignal(int sig);
    virtual bool handleIdle();
    virtual bool filterEvent(const XEvent &xev);
    virtual void actionPerformed(YAction action, unsigned int modifiers);

    virtual void handleMsgBox(YMsgBox *msgbox, int operation);
    virtual void handleSMAction(WMAction message);

    void doLogout(RebootShutdown reboot);
    void logout();
    void cancelLogout();

    // drop ties to own clients/windows since those are now destroyed by unmanageClients
    inline void clientsAreUnmanaged() {
        fLogoutMsgBox = 0;
        aboutDlg = 0;
    }

#ifdef CONFIG_SESSION
    virtual void smSaveYourselfPhase2();
    virtual void smDie();
#endif

    void setFocusMode(FocusModels mode);
    void initFocusMode();
    void initFocusCustom();

    virtual void restartClient(const char *path, char *const *args);
    virtual void runOnce(const char *resource, long *pid,
                         const char *path, char *const *args);
    virtual void runCommandOnce(const char *resource, const char *cmdline, long *pid);
    bool mapClientByPid(const char* resource, long pid);
    bool mapClientByResource(const char* resource, long *pid);

    static YCursor sizeRightPointer;
    static YCursor sizeTopRightPointer;
    static YCursor sizeTopPointer;
    static YCursor sizeTopLeftPointer;
    static YCursor sizeLeftPointer;
    static YCursor sizeBottomLeftPointer;
    static YCursor sizeBottomPointer;
    static YCursor sizeBottomRightPointer;
    static YCursor scrollLeftPointer;
    static YCursor scrollRightPointer;
    static YCursor scrollUpPointer;
    static YCursor scrollDownPointer;

    static ref<YIcon> getDefaultAppIcon();

    bool hasCtrlAltDelete() const { return ctrlAltDelete != 0; }
    CtrlAltDelete* getCtrlAltDelete();
    bool hasSwitchWindow() const { return switchWindow != 0; }
    SwitchWindow* getSwitchWindow();
    const char* getConfigFile() const { return configFile; }
    FocusModels getFocusMode() const { return focusMode; }

private:
    char** mainArgv;
    const char* configFile;

    // XXX: these pointers are PITA because they can become wild when objects
    // are destroyed independently by manager. What we need is something like std::weak_ptr...
    YMsgBox *fLogoutMsgBox;
    AboutDlg* aboutDlg;

    CtrlAltDelete* ctrlAltDelete;
    SwitchWindow* switchWindow;

    void runRestart(const char *path, char *const *args);

    FocusModels focusMode;
    Window managerWindow;

    static void initAtoms();
    static void initPointers();
    static void initIcons();
    static void termIcons();
    static void initIconSize();
    static void initPixmaps();
};

extern YWMApp * wmapp;

extern YMenu *windowMenu;
extern YMenu *layerMenu;
extern YMenu *moveMenu;
extern YMenu *trayMenu;
extern YMenu *windowListMenu;
extern YMenu *windowListPopup;
extern YMenu *windowListAllPopup;

extern YMenu *logoutMenu;

class ObjectMenu;
extern ObjectMenu *rootMenu;

class KProgram;
extern YObjectArray<KProgram> keyProgs;
extern RebootShutdown rebootOrShutdown;

#endif

// vim: set sw=4 ts=4 et:
